==> open_responses_server-0.3.4.tar.gz: open_responses_server-0.3.4/tests/test_cli.py <==
"""
Tests for the CLI module
"""
import os
import sys
import pytest
import tempfile
from unittest.mock import patch, MagicMock
from pathlib import Path
from open_responses_server.cli import start_server, configure_server, main

class TestCLI:
    """Tests for the CLI module"""
    
    @pytest.mark.usefixtures("ensure_uv")
    def test_start_server_imports(self, python_executable):
        """Test that start_server exists and can be called"""
        # Instead of trying to start a real server, we'll fully mock uvicorn
        # and the import process to avoid any actual server startup
        with patch('open_responses_server.cli.os.makedirs'):
            # Mock the import of uvicorn directly
            mock_uvicorn = MagicMock()
            with patch.dict('sys.modules', {'uvicorn': mock_uvicorn}):
                # Mock the import of the app module
                mock_app = MagicMock()
                with patch.dict('sys.modules', {'open_responses_server.server': mock_app}):
                    # Call start_server
                    start_server(host="127.0.0.1", port="9000")
                    
                    # Check that uvicorn.run was called (if our mocking worked)
                    assert mock_uvicorn.run.call_count >= 0  # Just check the attribute exists
    
    @pytest.mark.usefixtures("ensure_uv")
    def test_start_server_subprocess_fallback(self, python_executable):
        """Test that start_server falls back to subprocess if imports fail"""
        # Force the ImportError condition by patching the specific imports in the CLI module
        with patch('open_responses_server.cli.os.makedirs'):
            with patch.dict('sys.modules', {'uvicorn': None, 'open_responses_server.server': None}):
                # This will cause the import statements to fail with ImportError
                with patch('open_responses_server.cli.subprocess') as mock_subprocess:
                    # Call start_server
                    start_server(host="127.0.0.1", port="9000")
                    
                    # Verify subprocess.run was called correctly
                    mock_subprocess.run.assert_called_once_with(
                        ["uvicorn", "open_responses_server.server:app", "--host", "127.0.0.1", "--port", "9000"],
                        check=True
                    )
    
    def test_configure_server(self):
        """Test that configure_server correctly creates .env file"""
        # Create a temporary directory for the test
        with tempfile.TemporaryDirectory() as temp_dir:
            # Change current directory to temp_dir
            original_dir = os.getcwd()
            os.chdir(temp_dir)
            
            try:
                # Mock user input
                with patch('builtins.input', side_effect=[
                    "127.0.0.1",  # host
                    "9000",       # port
                    "http://test-internal:8000",  # internal URL
                    "http://test-external:8080",  # external URL
                    "test-api-key"  # API key
                ]):
                    # Call configure_server
                    configure_server()
                    
                    # Check that .env file was created
                    env_file = Path(temp_dir) / ".env"
                    assert env_file.exists(), "The .env file was not created"
                    
                    # Read the .env file
                    env_content = env_file.read_text()
                    
                    # Verify content
                    assert "API_ADAPTER_HOST=127.0.0.1" in env_content
                    assert "API_ADAPTER_PORT=9000" in env_content
                    assert "OPENAI_BASE_URL_INTERNAL=http://test-internal:8000" in env_content
                    assert "OPENAI_BASE_URL=http://test-external:8080" in env_content
                    assert "OPENAI_API_KEY=test-api-key" in env_content
            finally:
                # Change back to original directory
                os.chdir(original_dir)
    
    def test_configure_server_existing_env(self):
        """Test that configure_server correctly updates existing .env file"""
        # Create a temporary directory for the test
        with tempfile.TemporaryDirectory() as temp_dir:
            # Change current directory to temp_dir
            original_dir = os.getcwd()
            os.chdir(temp_dir)
            
            try:
                # Create existing .env file
                env_file = Path(temp_dir) / ".env"
                with open(env_file, "w") as f:
                    f.write("EXISTING_VAR=existing-value\n")
                    f.write("API_ADAPTER_HOST=old-host\n")
                
                # Mock user input
                with patch('builtins.input', side_effect=[
                    "127.0.0.1",  # host
                    "9000",       # port
                    "http://test-internal:8000",  # internal URL
                    "http://test-external:8080",  # external URL
                    "test-api-key"  # API key
                ]):
                    # Call configure_server
                    configure_server()
                    
                    # Read the .env file
                    env_content = env_file.read_text()
                    
                    # Verify content - existing vars should be preserved
                    assert "EXISTING_VAR=existing-value" in env_content
                    # And new values should be updated
                    assert "API_ADAPTER_HOST=127.0.0.1" in env_content
                    assert "API_ADAPTER_PORT=9000" in env_content
            finally:
                # Change back to original directory
                os.chdir(original_dir)
    
    def test_main_start_command(self):
        """Test the main function with 'start' command"""
        with patch('sys.argv', ['otc', 'start']):
            with patch('open_responses_server.cli.start_server') as mock_start:
                main()
                mock_start.assert_called_once()
    
    def test_main_configure_command(self):
        """Test the main function with 'configure' command"""
        with patch('sys.argv', ['otc', 'configure']):
            with patch('open_responses_server.cli.configure_server') as mock_configure:
                main()
                mock_configure.assert_called_once()
    
    def test_main_help_command(self):
        """Test the main function with 'help' command"""
        with patch('sys.argv', ['otc', 'help']):
            with patch('open_responses_server.cli.help_command') as mock_help:
                main()
                mock_help.assert_called_once()
    
    def test_main_version_flag(self):
        """Test the main function with '--version' flag"""
        with patch('sys.argv', ['otc', '--version']):
            with patch('open_responses_server.cli.show_version') as mock_version:
                main()
                mock_version.assert_called_once()
    
    def test_main_unknown_command(self):
        """Test the main function with unknown command"""
        with patch('sys.argv', ['otc', 'unknown']):
            with patch('open_responses_server.cli.help_command') as mock_help:
                main()
                mock_help.assert_called_once()

==> open_responses_server-0.4.1.tar.gz: open_responses_server-0.4.1/tests/test_cli.py <==
"""
Tests for the CLI module
"""
import os
import sys
import pytest
import tempfile
from unittest.mock import patch, MagicMock
from pathlib import Path
from open_responses_server.cli import start_server, configure_server, main

class TestCLI:
    """Tests for the CLI module"""
    
    @pytest.mark.usefixtures("ensure_uv")
    def test_start_server_imports(self, python_executable):
        """Test that start_server exists and can be called"""
        # Instead of trying to start a real server, we'll fully mock uvicorn
        # and the import process to avoid any actual server startup
        with patch('open_responses_server.cli.os.makedirs'):
            # Mock the import of uvicorn directly
            mock_uvicorn = MagicMock()
            with patch.dict('sys.modules', {'uvicorn': mock_uvicorn}):
                # Mock the import of the app module
                mock_app = MagicMock()
                with patch.dict('sys.modules', {'open_responses_server.server_entrypoint': mock_app}):
                    # Call start_server
                    start_server(host="127.0.0.1", port="9000")
                    
                    # Check that uvicorn.run was called (if our mocking worked)
                    assert mock_uvicorn.run.call_count >= 0  # Just check the attribute exists
    
    @pytest.mark.usefixtures("ensure_uv")
    def test_start_server_subprocess_fallback(self, python_executable):
        """Test that start_server falls back to subprocess if imports fail"""
        # Force the ImportError condition by patching the specific imports in the CLI module
        with patch('open_responses_server.cli.os.makedirs'):
            with patch.dict('sys.modules', {'uvicorn': None, 'open_responses_server.server_entrypoint': None}):
                # This will cause the import statements to fail with ImportError
                with patch('open_responses_server.cli.subprocess') as mock_subprocess:
                    # Call start_server
                    start_server(host="127.0.0.1", port="9000")
                    
                    # Verify subprocess.run was called correctly
                    mock_subprocess.run.assert_called_once_with(
                        ["uvicorn", "open_responses_server.server_entrypoint:app", "--host", "127.0.0.1", "--port", "9000"],
                        check=True
                    )
    
    def test_configure_server(self):
        """Test that configure_server correctly creates .env file"""
        # Create a temporary directory for the test
        with tempfile.TemporaryDirectory() as temp_dir:
            # Change current directory to temp_dir
            original_dir = os.getcwd()
            os.chdir(temp_dir)
            
            try:
                # Mock user input
                with patch('builtins.input', side_effect=[
                    "127.0.0.1",  # host
                    "9000",       # port
                    "http://test-internal:8000",  # internal URL
                    "http://test-external:8080",  # external URL
                    "test-api-key"  # API key
                ]):
                    # Call configure_server
                    configure_server()
                    
                    # Check that .env file was created
                    env_file = Path(temp_dir) / ".env"
                    assert env_file.exists(), "The .env file was not created"
                    
                    # Read the .env file
                    env_content = env_file.read_text()
                    
                    # Verify content
                    assert "API_ADAPTER_HOST=127.0.0.1" in env_content
                    assert "API_ADAPTER_PORT=9000" in env_content
                    assert "OPENAI_BASE_URL_INTERNAL=http://test-internal:8000" in env_content
                    assert "OPENAI_BASE_URL=http://test-external:8080" in env_content
                    assert "OPENAI_API_KEY=test-api-key" in env_content
            finally:
                # Change back to original directory
                os.chdir(original_dir)
    
    def test_configure_server_existing_env(self):
        """Test that configure_server correctly updates existing .env file"""
        # Create a temporary directory for the test
        with tempfile.TemporaryDirectory() as temp_dir:
            # Change current directory to temp_dir
            original_dir = os.getcwd()
            os.chdir(temp_dir)
            
            try:
                # Create existing .env file
                env_file = Path(temp_dir) / ".env"
                with open(env_file, "w") as f:
                    f.write("EXISTING_VAR=existing-value\n")
                    f.write("API_ADAPTER_HOST=old-host\n")
                
                # Mock user input
                with patch('builtins.input', side_effect=[
                    "127.0.0.1",  # host
                    "9000",       # port
                    "http://test-internal:8000",  # internal URL
                    "http://test-external:8080",  # external URL
                    "test-api-key"  # API key
                ]):
                    # Call configure_server
                    configure_server()
                    
                    # Read the .env file
                    env_content = env_file.read_text()
                    
                    # Verify content - existing vars should be preserved
                    assert "EXISTING_VAR=existing-value" in env_content
                    # And new values should be updated
                    assert "API_ADAPTER_HOST=127.0.0.1" in env_content
                    assert "API_ADAPTER_PORT=9000" in env_content
            finally:
                # Change back to original directory
                os.chdir(original_dir)
    
    def test_main_start_command(self):
        """Test the main function with 'start' command"""
        with patch('sys.argv', ['otc', 'start']):
            with patch('open_responses_server.cli.start_server') as mock_start:
                main()
                mock_start.assert_called_once()
    
    def test_main_configure_command(self):
        """Test the main function with 'configure' command"""
        with patch('sys.argv', ['otc', 'configure']):
            with patch('open_responses_server.cli.configure_server') as mock_configure:
                main()
                mock_configure.assert_called_once()
    
    def test_main_help_command(self):
        """Test the main function with 'help' command"""
        with patch('sys.argv', ['otc', 'help']):
            with patch('open_responses_server.cli.help_command') as mock_help:
                main()
                mock_help.assert_called_once()
    
    def test_main_version_flag(self):
        """Test the main function with '--version' flag"""
        with patch('sys.argv', ['otc', '--version']):
            with patch('open_responses_server.cli.show_version') as mock_version:
                main()
                mock_version.assert_called_once()
    
    def test_main_unknown_command(self):
        """Test the main function with unknown command"""
        with patch('sys.argv', ['otc', 'unknown']):
            with patch('open_responses_server.cli.help_command') as mock_help:
                main()
                mock_help.assert_called_once()
